"""removed unique logged in user

Peek Plugin Database Migration Script

Revision ID: 5e33c6b788fd
Revises: 3fd59734e444
Create Date: 2019-07-19 15:00:09.318828

"""

# revision identifiers, used by Alembic.
revision = '5e33c6b788fd'
down_revision = '3fd59734e444'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa
import geoalchemy2


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_constraint('UserLoggedIn_userName_key', 'UserLoggedIn', schema='core_user', type_='unique')
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_unique_constraint('UserLoggedIn_userName_key', 'UserLoggedIn', ['userName'], schema='core_user')
    # ### end Alembic commands ###



"""updated settings

Peek Plugin Database Migration Script

Revision ID: 7e3f668edf0e
Revises: 2209cf338e6d
Create Date: 2019-08-03 20:20:32.348282

"""

# revision identifiers, used by Alembic.
revision = '7e3f668edf0e'
down_revision = '2209cf338e6d'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa
import geoalchemy2


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column('UserLoggedIn', sa.Column('isFieldLogin', sa.Boolean(), nullable=True), schema='core_user')
    # ### end Alembic commands ###

    op.execute('''
    DELETE FROM core_user."SettingProperty"
    WHERE "key" = 'Allow Multi Device Logins'
    ''')

    op.execute('''
    UPDATE core_user."SettingProperty"
    SET "key" = 'Field Show Login as List'
    WHERE "key" = 'Show Login as List'
    ''')

    op.execute('''
    UPDATE core_user."SettingProperty"
    SET "key" = 'Field Show Vehicle Input'
    WHERE "key" = 'Show Vehicle Input'
    ''')


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('UserLoggedIn', 'isFieldLogin', schema='core_user')
    # ### end Alembic commands ###



import logging
from typing import List

from peek_core_user._private.server.auth_connectors.InternalAuth import InternalAuth
from peek_core_user._private.server.auth_connectors.LdapAuth import LdapAuth
from peek_core_user._private.storage.Setting import \
    globalSetting, LDAP_AUTH_ENABLED, \
    INTERNAL_AUTH_ENABLED_FOR_ADMIN
from peek_plugin_base.storage.DbConnection import DbSessionCreator
from twisted.cred.error import LoginFailed
from vortex.DeferUtil import deferToThreadWrapWithLogger

logger = logging.getLogger(__name__)


class AdminAuthController:

    def __init__(self, dbSessionCreator: DbSessionCreator):
        self._dbSessionCreator: DbSessionCreator = dbSessionCreator

    def shutdown(self):
        pass

    @deferToThreadWrapWithLogger(logger)
    def check(self, userName, password) -> List[str]:
        if not password:
            raise LoginFailed("Password is empty")

        ormSession = self._dbSessionCreator()
        try:
            lastException = None

            # TRY INTERNAL IF ITS ENABLED
            try:
                if globalSetting(ormSession, INTERNAL_AUTH_ENABLED_FOR_ADMIN):
                    return InternalAuth().checkPassBlocking(ormSession, userName,
                                                            password,
                                                            InternalAuth.FOR_ADMIN)

            except Exception as e:
                lastException = e

            # TRY LDAP IF ITS ENABLED
            try:
                if globalSetting(ormSession, LDAP_AUTH_ENABLED):
                    # TODO Make the client tell us if it's for office or field
                    return LdapAuth().checkPassBlocking(ormSession, userName,
                                                        password, LdapAuth.FOR_ADMIN)

            except Exception as e:
                lastException = e

            if lastException:
                raise lastException

            raise Exception(
                "No authentication handlers are enabled, enable one in settings")

        finally:
            ormSession.close()



import os
import shutil

from setuptools import find_packages
from setuptools import setup

pip_package_name = "peek-core-user"
py_package_name = "peek_core_user"

package_version = '2.5.5'

egg_info = "%s.egg-info" % pip_package_name
if os.path.isdir(egg_info):
    shutil.rmtree(egg_info)

if os.path.isfile('MANIFEST'):
    os.remove('MANIFEST')

excludePathContains = ('__pycache__', 'node_modules', 'platforms', 'dist')
excludeFilesEndWith = ('.pyc', '.js', '.js.map', '.lastHash')
excludeFilesStartWith = ()

dependencies = [
    'peek-plugin-base',
    'python-ldap'
]


def find_package_files():
    paths = []
    for (path, directories, filenames) in os.walk(py_package_name):
        if [e for e in excludePathContains if e in path]:
            continue

        for filename in filenames:
            if [e for e in excludeFilesEndWith if filename.endswith(e)]:
                continue

            if [e for e in excludeFilesStartWith if filename.startswith(e)]:
                continue

            paths.append(os.path.join(path[len(py_package_name) + 1:], filename))

    return paths


package_files = find_package_files()

setup(
    name=pip_package_name,
    packages=find_packages(exclude=["*.tests", "*.tests.*", "tests.*", "tests"]),
    package_data={'': package_files},
    install_requires=dependencies,
    zip_safe=False, version=package_version,
    description='Peek Plugin - UserDb - This is the No Operation test/example plugin',
    author='Synerty',
    author_email='contact@synerty.com',
    url='https://github.com/Synerty/%s' % py_package_name,
    download_url='https://github.com/Synerty/%s/tarball/%s' % (
        pip_package_name, package_version),
    keywords=['Peek', 'Python', 'Platform', 'synerty'],
    classifiers=[],
)



import logging

from peek_core_user._private.server.api.UserApi import UserApi
from peek_core_user._private.storage.InternalUserTuple import InternalUserTuple
from peek_core_user._private.storage.UserLoggedIn import UserLoggedIn
from peek_core_user._private.tuples.UserLoggedInTuple import UserLoggedInTuple
from peek_core_user.tuples.UserListItemTuple import UserListItemTuple
from sqlalchemy.orm.exc import NoResultFound
from twisted.internet.defer import Deferred
from vortex.DeferUtil import deferToThreadWrapWithLogger
from vortex.Payload import Payload
from vortex.TupleSelector import TupleSelector
from vortex.handler.TupleDataObservableHandler import TuplesProviderABC

logger = logging.getLogger(__name__)


class UserLoggedInTupleProvider(TuplesProviderABC):
    def __init__(self, dbSessionCreator,
                 ourApi: UserApi):
        self._dbSessionCreator = dbSessionCreator
        self._ourApi = ourApi

        from peek_core_user.server.UserApiABC import UserApiABC
        assert isinstance(self._ourApi, UserApiABC), (
            "We didn't get a UserApiABC")

    @deferToThreadWrapWithLogger(logger)
    def makeVortexMsg(self, filt: dict, tupleSelector: TupleSelector) -> Deferred:
        deviceToken = tupleSelector.selector["deviceToken"]

        session = self._dbSessionCreator()
        try:
            userLoggedIn = session.query(UserLoggedIn) \
                .filter(UserLoggedIn.deviceToken == deviceToken) \
                .one()

            internalUserTuple = session.query(InternalUserTuple) \
                .filter(InternalUserTuple.userName == userLoggedIn.userName) \
                .one()

            userDetails = UserListItemTuple(userId=internalUserTuple.userName,
                                            displayName=internalUserTuple.userTitle)

        except NoResultFound:
            userDetails = None

        finally:
            session.close()

        tuples = [UserLoggedInTuple(deviceToken=deviceToken,
                                    userDetails=userDetails)]

        payloadEnvelope = Payload(filt=filt, tuples=tuples).makePayloadEnvelope()
        vortexMsg = payloadEnvelope.toVortexMsg()
        return vortexMsg



"""added ldap table

Peek Plugin Database Migration Script

Revision ID: 2209cf338e6d
Revises: 5e33c6b788fd
Create Date: 2019-07-31 20:32:15.541766

"""

# revision identifiers, used by Alembic.
revision = '2209cf338e6d'
down_revision = '5e33c6b788fd'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa
import geoalchemy2


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table('LdapSetting',
    sa.Column('id', sa.Integer(), autoincrement=True, nullable=False),
    sa.Column('ldapTitle', sa.String(), nullable=False),
    sa.Column('ldapDomain', sa.String(), nullable=False),
    sa.Column('ldapUri', sa.String(), nullable=False),
    sa.Column('ldapCNFolders', sa.String(), nullable=True),
    sa.Column('ldapOUFolders', sa.String(), nullable=True),
    sa.Column('adminEnabled', sa.Boolean(), server_default='0', nullable=False),
    sa.Column('desktopEnabled', sa.Boolean(), server_default='0', nullable=False),
    sa.Column('mobileEnabled', sa.Boolean(), server_default='0', nullable=False),
    sa.Column('ldapGroups', sa.String(), nullable=True),
    sa.PrimaryKeyConstraint('id'),
    sa.UniqueConstraint('ldapTitle'),
    schema='core_user'
    )
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_table('LdapSetting', schema='core_user')
    # ### end Alembic commands ###
